import React, { useState, useRef, useEffect, useMemo } from "react";
import {
  Form,
  Input,
  Button,
  Space,
  Table,
  Modal,
  Image,
  Select,
  message,
  // Upload,
  DatePicker,
  Radio,
  Tag,
  // Spin,
} from "antd";
import { LoadingOutlined, PlusOutlined, LayoutFilled } from "@ant-design/icons";
import zh from "antd/es/date-picker/locale/zh_CN";
import baseRequest from "../../utils/baseRequest";
import UploadImgs from "../../components/UploadImgs";
import { formatDeadline } from "../../utils/tools";
import PagesManage from "../../components/PagesManage";
const NoticesContent = (props) => {
  //控制创建动态modal是否出现
  const [isModalOpen, setIsModalOpen] = useState(false);
  const [isPagesModalOpen, setIsPagesModalOpen] = useState(false);
  const [loading, setLoading] = useState(false);
  // const [assets, setAssets] = useState([]);
  const [isSubmitting, setIsSubmitting] = useState(false);
  //提交创建动态
  const [form] = Form.useForm();

  const { TextArea } = Input;
  const current = props.current;

  //表头
  const columns = [
    {
      title: "推送消息类型",
      dataIndex: "n_type",
      key: "n_type",
      filters: [
        {
          text: "系统通知",
          value: 0,
        },
        {
          text: "付费通知",
          value: 1,
        },
        {
          text: "活动通知",
          value: 2,
        },
        {
          text: "审核通知",
          value: 3,
        },
      ],
      filterMode: "tree",
      onFilter: (value, record) => record.status == value,
      render: (data) => {
        return (
          <div>
            {data == 0
              ? "系统通知"
              : data == 1
              ? "付费通知"
              : data == 2
              ? "活动通知"
              : "审核通知"}
          </div>
        );
      },
    },
    {
      title: "推送消息正文",
      dataIndex: "message",
      key: "message",
    },
    {
      title: "推送消息主图",
      dataIndex: "thumbnail",
      key: "thumbnail",
      render: (data) => (
        <div>
          {data
            ? data.images?.map((item, index) => (
                <Image
                  key={index}
                  src={item.urls[0]}
                  style={{ marginBottom: 10 }}
                />
              ))
            : "-"}
        </div>
      ),
    },
    {
      title: "链接标语",
      dataIndex: "link_text",
      key: "link_text",
      render: (data) => <div>{data || "-"}</div>,
    },
    {
      title: "链接",
      dataIndex: "params",
      key: "params",
      render: (data) => <div>{data || "-"}</div>,
    },
    {
      title: "推送时间",
      dataIndex: "push_time",
      key: "push_time",
      render: (data) => {
        return <div>{formatDeadline(data)}</div>;
      },
    },
    {
      title: "推送角色",
      dataIndex: "obj_mids",
      key: "obj_mids",
      render: (data) => (
        <div>
          {data?.length > 0 ? data.map((it) => <span>{it}</span>) : "-"}
        </div>
      ),
    },
    {
      title: "推送角色类型",
      dataIndex: "obj_type",
      key: "obj_type",
      render: (data) => {
        return (
          <div>
            {data == 0
              ? "所有主播"
              : data == 1
              ? "所有个人"
              : data == 2
              ? "所有主播和个人"
              : "自定义角色"}
          </div>
        );
      },
    },
    {
      title: "推送状态",
      dataIndex: "status",
      key: "status",
      filters: [
        {
          text: "待推送",
          value: 0,
        },
        {
          text: "已推送",
          value: 1,
        },
        {
          text: "推送失败",
          value: 2,
        },
        {
          text: "已撤销",
          value: 3,
        },
      ],
      filterMode: "tree",
      onFilter: (value, record) => record.status == value,
      render: (data) => (
        <div>
          {data == 0 ? (
            <Tag color="green">待推送</Tag>
          ) : data == 1 ? (
            <Tag color="blue">已推送</Tag>
          ) : data == 2 ? (
            <Tag color="red">推送失败</Tag>
          ) : (
            <Tag color="orange">已撤销</Tag>
          )}
        </div>
      ),
    },
    {
      title: "操作",
      dataIndex: "opeartion",
      key: "opeartion",
      render: (_, record) => {
        console.log("eeeeee", record);
        return (
          <div>
            <Space>
              <Space.Compact direction="vertical">
                {record.status == 0 && (
                  <Button
                    style={{ background: "#ff4d4f", color: "#fff" }}
                    onClick={() => handleCancleNotice(record?.id)}
                  >
                    撤销通知
                  </Button>
                )}
              </Space.Compact>
            </Space>
          </div>
        );
      },
    },
  ];
  //给表单绑定ref
  const formRef = useRef(null);
  //点击修改状态按钮
  const onClickSubmit = (record) => {
    formRef.current.key = record.key;
    formRef.current.btn = "submit";
    formRef.current.submit();
  };
  //点击无效按钮
  const onClickInvalid = (record) => {
    formRef.current.key = record.key;
    formRef.current.btn = "invalid";
    formRef.current.submit();
  };
  //点击迭代相关按钮
  const onClickIteration = (record) => {
    formRef.current.key = record.key;
    formRef.current.btn = "iteration";
    formRef.current.submit();
  };
  //通知撤销
  const handleCancleNotice = async (nid) => {
    try {
      const base = baseRequest();
      const response = await fetch("/op/notification/cancel", {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          nid,
          ...base,
        }),
      });
      const temData = await response.json();
      if (temData.ret === -1) {
        alert(temData.msg);
        return;
      }
      message.success("撤销成功");
    } catch (error) {
      console.error(error);
    }
  };
  const buddhistLocale = {
    ...zh,
    lang: {
      ...zh.lang,
      fieldDateFormat: "YYYY-MM-DD",
      fieldDateTimeFormat: "YYYY-MM-DD HH:mm:ss",
      yearFormat: "YYYY",
      cellYearFormat: "YYYY",
    },
  };
  //获取数据
  const [data, setData] = useState([]);
  const [offset, setOffset] = useState(0);
  const [more, setMore] = useState(1);
  const [formData, setFormData] = useState({
    message: "",
    n_type: 0,
    obj_mids: [],
    // push_time: 1111111111111,
    params: null,
    pageName: null,
    link: null,
    action: null,
    link_text: null,
    thumbnail: null,
    obj_type: "0",
  });
  const getData = async () => {
    if (!more) return;
    let querryStatus;
    switch (current) {
      case "pushing":
        querryStatus = 0;
        break;
      case "pushed":
        querryStatus = 1;
        break;
      case "fail":
        querryStatus = 2;
        break;
      case "backed":
        querryStatus = 3;
        break;
      default:
        break;
    }
    try {
      const base = baseRequest();
      const response = await fetch("/op/notification/list", {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          n_type: 0,
          // push_time: 0,
          // status: querryStatus,
          // offset: offset,
          // limit: 200,
          ...base,
        }),
      });
      const temData = await response.json();
      console.log("response", temData);

      if (temData.ret === -1) {
        alert(temData.msg);
        return;
      }
      setShowData([...temData.data.list]);
      setOffset(temData.data.offset);
      setMore(temData.data.more);
    } catch (error) {
      console.error(error);
    }
  };
  useEffect(() => {
    getData();
  }, [current]);

  //展示的数据
  const [showData, setShowData] = useState(data);

  //表单提交失败
  const onFinishFailed = (errorInfo) => {
    console.log("Failed:", errorInfo);
  };
  //关闭弹窗
  const handleCancelModal = () => {
    form.resetFields();
    setIsModalOpen(false);
  };
  const handleSubmit = async (value) => {
    // if (!selectedUser) {
    //   alert("还未选中用户");
    //   return;
    // }
    const newValue = { ...value };
    newValue["thumbnail"] = formData.thumbnail;
    newValue["obj_mids"] = newValue.obj_mids
      ?.split(" ")
      .map((it) => Number(it));
    newValue["push_time"] = Math.ceil(
      new Date(newValue.push_time).getTime() / 1000
    );
    newValue["obj_type"] = parseInt(newValue.obj_type, 10);
    console.log("newValue", newValue);

    debugger;
    try {
      const base = baseRequest();
      const response = await fetch(`/op/notification/create`, {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          sub_mid: 0,
          ...base,
          ...newValue,
        }),
      });
      const data = await response.json();
      if (data.ret === -1) {
        alert(data.msg);
        return;
      }
      message.success("发布成功");
    } catch (error) {
      console.error(error);
    }

    form.resetFields();
  };
  const onTimeOk = (value) => {
    console.log("onOk: ", value);
  };
  const uploadButton = (
    <button
      style={{
        border: 0,
        background: "none",
      }}
      type="button"
    >
      {loading ? <LoadingOutlined /> : <PlusOutlined />}
      <div
        style={{
          marginTop: 8,
        }}
      >
        上传图片
      </div>
    </button>
  );
  return (
    <div style={{ marginLeft: 20, marginRight: 20 }}>
      <div className="flex justify-between items-center">
        <Button
          type="default"
          className="mt-4 mb-4 float-right"
          onClick={() => setIsPagesModalOpen(true)}
          icon={<LayoutFilled className="text-primary" />}
        >
          页面管理
        </Button>
        <Button
          type="primary"
          className="mt-4 mb-4 float-right"
          onClick={() => setIsModalOpen(true)}
        >
          新建推送+
        </Button>
      </div>
      <Table
        columns={columns}
        dataSource={showData}
        pagination={{ pageSize: 20 }}
        scroll={{ y: window.innerHeight - 300 }}
      />
      {/* 重复判断isModalOpen是为了重新渲染ImageUploader和VideoUploader组件 */}
      <Modal
        title="新建消息推送通知"
        footer={null}
        open={isModalOpen}
        onCancel={handleCancelModal}
      >
        <Form
          className="mt-4 flex flex-col"
          form={form}
          onFinish={handleSubmit}
          layout="vertical"
          initialValues={formData}
        >
          <Form.Item
            label="添加活动消息正文（上限250字）"
            name="message"
            rules={[
              {
                required: true,
                message: "请填写活动消息内容",
              },
            ]}
            className="mb-6"
          >
            <TextArea maxLength={250} showCount />
          </Form.Item>
          <Form.Item
            label="推送消息类型"
            name="n_type"
            rules={[
              {
                required: true,
                message: "请选择推送消息类型",
              },
            ]}
            className="mb-6"
          >
            <Select
              // defaultValue={1}
              style={{
                width: 120,
              }}
              // onChange={handleChange}
              options={[
                {
                  value: 0,
                  label: "系统通知",
                },
                {
                  value: 1,
                  label: "付费通知",
                },
                {
                  value: 2,
                  label: "活动通知",
                },
                {
                  value: 3,
                  label: "审核通知",
                },
              ]}
            />
          </Form.Item>
          <Form.Item
            label="推送角色"
            name="obj_type"
            rules={[
              {
                required: true,
                message: "请填写推送角色",
              },
            ]}
            className={formData.obj_type == 3 ? "mb-2" : "mb-6"}
          >
            <div>
              <Radio.Group
                defaultValue={0}
                onChange={(e) => {
                  console.log(e.target.value);
                  setFormData((old) => {
                    return {
                      ...old,
                      obj_type: e.target.value,
                    };
                  });
                }}
              >
                <Radio value={0}>所有主播</Radio>
                <Radio value={1}>所有个人</Radio>
                <Radio value={2}>所有主播和个人</Radio>
                <Radio value={3}>自定义角色</Radio>
              </Radio.Group>
            </div>
          </Form.Item>
          {formData.obj_type == 3 && (
            <Form.Item
              name="obj_mids"
              rules={[
                {
                  required: true,
                  message: "请填写推送角色",
                },
              ]}
              className="mb-6"
            >
              <div>
                <TextArea
                  value={formData.obj_mids}
                  onChange={(e) =>
                    setFormData((old) => ({
                      ...old,
                      obj_mids: e.target.value,
                    }))
                  }
                  placeholder="用户ID以空格隔开"
                />
              </div>
            </Form.Item>
          )}

          <Form.Item
            label="推送时间"
            name="push_time"
            format="YYYY-MM-DD HH:mm"
            rules={[
              {
                required: true,
                message: "请选择时间",
              },
            ]}
            className="mb-6"
          >
            <DatePicker
              showTime
              // locale={{
              //   lang: { locale: "zh_CN", placeholder: "选择日期时间" },
              // }}
              locale={buddhistLocale}
              onChange={(value, dateString) => {
                // console.log("Time: ", new Date());
                console.log("Selected Time: ", value);
                console.log("Formatted Selected Time: ", dateString);
              }}
              onOk={onTimeOk}
            />
          </Form.Item>
          <p className="mb-2">添加跳转内容：</p>
          <Space
            direction="vertical"
            className="bg-[#00000011] rounded-md p-4 mb-4"
          >
            <Form.Item label="跳转形式" name="action" className="mb-2">
              <Select
                placeholder="选择跳转形式"
                style={{
                  width: 120,
                }}
                // onChange={handleChange}
                options={[
                  {
                    value: "app",
                    label: "APP内跳转",
                  },
                  {
                    value: "h5",
                    label: "内部H5跳转",
                  },
                  {
                    value: "out",
                    label: "外部浏览器跳转",
                  },
                ]}
                onChange={(value) => {
                  setFormData((old) => ({
                    ...old,
                    action: value,
                  }));
                }}
              />
            </Form.Item>

            {formData.action && (
              <div>
                <div>
                  {formData.action == "out" ? (
                    <Form.Item
                      rules={[
                        {
                          required: true,
                          message: "请填写具体链接地址",
                        },
                      ]}
                      label="添加链接"
                      name="link"
                      className="mb-2"
                    >
                      <Input
                        onChange={(value) => {
                          console.log("value", value);
                          setFormData((old) => ({
                            ...old,
                            link: value.target.value,
                          }));
                        }}
                      />
                    </Form.Item>
                  ) : (
                    <Space direction="vertical" className="w-full">
                      <label>
                        <span className="text-[red] mr-1">*</span>添加链接
                      </label>
                      <div className="flex items-center">
                        <Form.Item name="pageName" className="mb-2">
                          <Select
                            placeholder="选择页面"
                            style={{
                              width: 120,
                            }}
                            // onChange={handleChange}
                            options={[
                              {
                                value: "app",
                                label: "空间主页",
                              },
                              {
                                value: "h5",
                                label: "活动页",
                              },
                            ]}
                          />
                        </Form.Item>
                        <div className="-mt-2 mx-2">?</div>
                        <Form.Item
                          layout="horizontal"
                          name="params"
                          className="mb-2 w-full flex-1"
                          style={{ width: "100%" }}
                        >
                          <Input
                            className="w-full"
                            placeholder="填写连接参数"
                            onChange={(value) => {
                              console.log("value", value);
                              setFormData((old) => ({
                                ...old,
                                params: value.target.value,
                              }));
                            }}
                          />
                        </Form.Item>
                      </div>
                    </Space>
                  )}
                </div>
                <Form.Item
                  label="添加链接标题"
                  name="link_text"
                  rules={[
                    {
                      required: true,
                      message: "请填写链接标题",
                    },
                  ]}
                  className="mb-2"
                >
                  <Input placeholder="链接标题" />
                </Form.Item>
                <Form.Item
                  label="添加主图"
                  name="thumbnail"
                  // rules={[
                  //   {
                  //     required: true,
                  //     message: "请上传主图",
                  //   },
                  // ]}
                  className="mb-2"
                >
                  <UploadImgs
                    assets={formData.thumbnail}
                    getImgs={(value) => {
                      setFormData((old) => ({
                        ...old,
                        thumbnail: { image_ids: [value] },
                      }));
                    }}
                    multiple={false}
                  />
                </Form.Item>
              </div>
            )}
          </Space>
          <Button type="primary" htmlType="submit">
            确认
          </Button>
        </Form>
      </Modal>
      <Modal
        title="页面管理"
        footer={null}
        open={isPagesModalOpen}
        style={{ minWidth: 800 }}
        onCancel={() => setIsPagesModalOpen(false)}
      >
        <PagesManage />
      </Modal>
    </div>
  );
};

export default function Notices() {
  return (
    <div>
      <NoticesContent />
    </div>
  );
}
